# Spacex-API (spacexpypi)
PyPi Integration to the SpaceX API

## Available Methods

There are three available methods in this library which will return the json payload from the appropriate SpaceX API.

### get_roadster_status()
Returns the current status and details of the SpaceX Tesla Roadster.

### get_next_launch()
Returns the information on the next planned SpaceX launch.

### get_upcoming_launches()
Returns all upcoming launches that are planned with SpaceX.